function v=compute_ekman_surge_cexn(vmax,rmax,r35,vt,phi,phi_in,w,a,n,lat)
% Computes ekman_surge_cexn
% Script automatically generated by fit_ekman_surge_cexn.m
% Inputs : 
% vmax           = Vmax (km/h)
% rmax           = Rmax (km)
% r35            = R35 (km)
% vt             = forward speed (km/h)
% phi            = track angle (deg)
% phi_in         = inflow angle (deg)
% w              = shelf width (km)
% a              = Dean slope a (-)
% n              = Mannings n
% lat            = latitude (deg)

% R2    = 0.35665
% RMSE  = 41.7661
% MEAN  = 211.6253
% RANGE = 102.7921 - 296.5781

beta( 1 )= 1.7585e+01 ;
beta( 2 )= 2.6414e-01 ;
beta( 3 )= 2.6596e-01 ;

v=beta(1)*w.^beta(2).*(90-phi).^beta(3);
